AnimProxy - Rabbyt Reference

Documentation Index | From module rabbyt.anims.

# AnimProxy

`AnimProxy(value, cache=False)`

An anim that simply returns the value of another anim.

`value` is the value that can be returned. It can be a number, a function, or another anim.

If `cache` is True, a cached value will be called when the anim is accessed a second time without the global time changing.

## Properties

### value

The value that this anim will return.

You can assign another anim here, and it's value will be returned.